==> haskell-conversion-bytestring-1.0.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conversion-bytestring.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conversion-bytestring
version: 1.0.1
id: conversion-bytestring-1.0.1-C4EQTeKNsCmAFHtg6gAS6Z
key: conversion-bytestring-1.0.1-C4EQTeKNsCmAFHtg6gAS6Z
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/conversion-bytestring
synopsis: "Conversion" instances for the "bytestring" library
category: Control, Data, Conversion
abi: 262ad9da8f29656c1e1ed35a169436d2
exposed: True
exposed-modules:
    Conversion.ByteString
import-dirs: /usr/lib/ghc-8.4.3/site-local/conversion-bytestring-1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/conversion-bytestring-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/conversion-bytestring-1.0.1
hs-libraries: HSconversion-bytestring-1.0.1-C4EQTeKNsCmAFHtg6gAS6Z
depends:
    bytestring-0.10.8.2 conversion-1.2.1-GVMjU1MOI8glyOGflZe9J
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conversion-1.2.1-GVMjU1MOI8glyOGflZe9J=888a52c8d00cd845bc8154c6298a150f
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-conversion-bytestring/html/conversion-bytestring.haddock
haddock-html: /usr/share/doc/haskell-conversion-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conversion-bytestring-1.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conversion-bytestring.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conversion-bytestring
version: 1.0.1
id: conversion-bytestring-1.0.1-Ic7N6B6esWlCE6vztSKndy
key: conversion-bytestring-1.0.1-Ic7N6B6esWlCE6vztSKndy
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/conversion-bytestring
synopsis: "Conversion" instances for the "bytestring" library
category: Control, Data, Conversion
abi: 8fac46f741f0f8abbb1f52321ea1ff69
exposed: True
exposed-modules:
    Conversion.ByteString
import-dirs: /usr/lib/ghc-8.6.1/site-local/conversion-bytestring-1.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/conversion-bytestring-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/conversion-bytestring-1.0.1
hs-libraries: HSconversion-bytestring-1.0.1-Ic7N6B6esWlCE6vztSKndy
depends:
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s bytestring-0.10.8.2
    conversion-1.2.1-8xBru6GHTVg3lh5nBJWaVP
haddock-interfaces: /usr/share/doc/haskell-conversion-bytestring/html/conversion-bytestring.haddock
haddock-html: /usr/share/doc/haskell-conversion-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
